<?php

namespace App\DataTables;

use Yajra\DataTables\DataTableAbstract;
use Yajra\DataTables\Html\Builder as HtmlBuilder;
use Yajra\DataTables\Html\Column;
use Yajra\DataTables\Services\DataTable;
use Illuminate\Support\Facades\Http;

class TrialDataTable extends DataTable
{
    /**
     * Build the DataTable class.
     *
     * @param QueryBuilder $query Results from query() method.
     */
    public function dataTable($query): DataTableAbstract
    {
        return datatables()->of($query);
    }

    /**
     * Get the query source of dataTable.
     */
    public function query()
    {
        // Fetch data from the external API
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/trials');
        
        // Check if the response is successful
        if ($response->successful()) {
            // Return the JSON data from 'data' key
            return collect($response->json()['data']);
        }

        // Return an empty collection if the API call fails
        return collect([]);
    }

    /**
     * Optional method if you want to use the html builder.
     */
    public function html(): HtmlBuilder
    {
        return $this->builder()
                    ->setTableId('trial_table') // Ensure this matches your HTML table ID
                    ->columns($this->getColumns())
                    ->minifiedAjax()
                    ->orderBy(1)
                    ->selectStyleSingle();
    }

    /**
     * Get the dataTable columns definition.
     */
    public function getColumns(): array
    {
        return [
            Column::computed('action')
                  ->exportable(false)
                  ->printable(false)
                  ->width(120)
                  ->addClass('text-center'),
            Column::make('id'),
            Column::make('lead_name'),
            Column::make('course_name'),
            Column::make('teacher_name'),
            Column::make('trial_time'),
        ];
    }

    /**
     * Get the filename for export.
     */
    protected function filename(): string
    {
        return 'Trial_' . date('YmdHis');
    }
}
