<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Http;
use Illuminate\Support\Facades\Log;

class AuthController extends Controller
{
    public function login_view()
    {
        // Redirect to the home page if already logged in
        if (session()->has('bearer_token')) {
            return redirect('/');
        }

        return view('auth.login');
    }

    public function login(Request $request)
    {
        // Validate the request
        $request->validate([
            'email' => 'required|email',
            'password' => 'required',
        ]);

        // Send request to external API
        $response = Http::post('https://microsols.com.au/api/public/api/login', [
            'email' => $request->email,
            'password' => $request->password,
        ]);

        // Check if the response is successful
        if ($response->successful()) {
            $data = $response->json();
            $token = 'Bearer ' . $data['access_token'];
            
            // Store token and user details in session
            session([
                'bearer_token' => $token,
                'user' => $data['user'],
                'permissions' => $data['user']['permissions'],
            ]);

            return redirect('/')->with('success', 'Logged in successfully');
        }

        return redirect()->route('login_view')->with('error', 'Unauthorized');
    }
    

    public function logout(Request $request)
    {
        // Get the bearer token from the session
        $token = session('bearer_token');

        // Send request to external API
        $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/logout');

        // Check if the response is successful
        if ($response->successful()) {
            // Forget the token in the session
            session()->forget(['bearer_token', 'user_role']);
            return redirect()->route('login_view')->with('success', 'Logged out successfully');
        } else {


            return redirect()->route('login_view')->with('error', 'Unable to logout');
        }
    }
}
