<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use App\DataTables\PermissionDataTable;

class PermissionController extends Controller
{
    public function permission_list(PermissionDataTable $dataTable)
    {
        return $dataTable->render('admin.roles_and_permissions.permission_list');
    }
    public function add_permission_form(Request $request)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/permissions', [
                'name' => $request->name,
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Permission added successfully']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add Permission.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    public function delete_permission($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/permissions/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Permission deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Permission'
            ], $response->status());
        }
    }
    public function get_permission($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/permissions/{$id}");

            if ($response->successful()) {
                return response()->json(['permission' => $response->json()]);
            } else {
                return response()->json(['permission' => 404, 'message' => 'Permission not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function update_permission_form(Request $request, $id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/permissions/{$id}", [
                'name' => $request->name,
               
            ]);
    
            if ($response->successful()) {
                return response()->json(['message' => 'Permission updated successfully.']);
            } else {
                return response()->json(['message' => 'Failed to update Lead.'], $response->permission());
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
}
