<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\DataTables\RolesDataTable;
use Illuminate\Support\Facades\Http;

class RolesController extends Controller
{

    public function fetch_roles(): array
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/roles');

        if ($response->successful()) {
            $roles = $response->json()['role'] ?? [];
            // Extract only the necessary columns
            $roles_list = array_map(function ($roles) {
                return [
                    'id' => $roles['id'],
                    'name' => $roles['name'],
                ];
            }, $roles);

            return $roles_list;
        }

        return [];
    }
    public function fetch_permissions(): array
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/permissions');

        if ($response->successful()) {
            $permissions = $response->json()['data'] ?? [];
            // Extract only the necessary columns
            $permission_list = array_map(function ($permissions) {
                return [
                    'id' => $permissions['id'],
                    'name' => $permissions['name'],
                ];
            }, $permissions);

            return $permission_list;
        }

        return [];
    }
    public function roles_list(RolesDataTable $dataTable)
    {
        $roles = $this->fetch_roles();
        $permissions = $this->fetch_permissions();
        return $dataTable->render('admin.roles_and_permissions.roles_list', compact('roles' ,'permissions'));
    }
    public function add_role_form(Request $request)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/roles', [
                'name' => $request->name,
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Role added successfully']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add Role.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    public function assign_permission(Request $request)
    {
        $request->validate([
            'role_id' => 'required',
            'permission_ids' => 'required|array',
            'permission_ids.*' => 'integer', // Ensure all IDs are integers
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/role-permissions', [
                'role_id' => $request->role_id,
                'permission_ids' => $request->permission_ids, // Fix to use permission_ids array
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Permissions assigned successfully']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to assign permissions.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    
    public function delete_role($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/roles/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Role deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Role'
            ], $response->status());
        }
    }
    public function get_role($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/roles/{$id}");

            if ($response->successful()) {
                return response()->json(['role' => $response->json()]);
            } else {
                return response()->json(['role' => 404, 'message' => 'Role not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function update_role_form(Request $request, $id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/roles/{$id}", [
                'name' => $request->name,
            ]);
    
            if ($response->successful()) {
                return response()->json(['message' => 'Role updated successfully.']);
            } else {
                return response()->json(['message' => 'Failed to update Lead.'], $response->permission());
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
}
