<?php

namespace App\Http\Controllers\Settings;

use Illuminate\Http\Request;
use App\DataTables\UsersDataTable;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Http;

class UserController extends Controller
{
    public function fetch_roles(): array
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/roles');

        if ($response->successful()) {
            $roles = $response->json()['role'] ?? [];
            // Extract only the necessary columns
            $roles_list = array_map(function ($roles) {
                return [
                    'id' => $roles['id'],
                    'name' => $roles['name'],
                ];
            }, $roles);

            return $roles_list;
        }

        return [];
    }
    public function user_list(UsersDataTable $dataTable)
    {
        $roles = $this->fetch_roles();
        return $dataTable->render('admin.settings.user_list',compact('roles'));
    }
    public function add_user_form(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email',
            'password' => 'required',
            'role_id' => 'required',
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/users', [
                'name' => $request->name,
                'email' => $request->email,
                'password' => $request->password,
                'role_id' => $request->role_id,
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'User added successfully']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add User.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    
    
    public function delete_user($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/users/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'User deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete User'
            ], $response->status());
        }
    }
    public function get_user($id)
    {
        
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/users/{$id}");

            if ($response->successful()) {
                return response()->json(['user' => $response->json()]);
            } else {
                return response()->json(['user' => 404, 'message' => 'User not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function update_user_form(Request $request, $id)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email',
            'password' => 'required',
            'role_id' => 'required',
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/users/{$id}", [
                'name' => $request->name,
                'email' => $request->email,
                'password' => $request->password,
                'role_id' => $request->role_id,
            ]);
    
            if ($response->successful()) {
                return response()->json(['message' => 'User updated successfully.']);
            } else {
                $error = $response->json();
                return response()->json([
                    'message' => $error['message'] ?? 'Failed to update User.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
    
}
