<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\DataTables\StatusDataTable;
use Illuminate\Support\Facades\Http;


class StatusController extends Controller
{
    public function status_list(StatusDataTable $dataTable)
    {
        return $dataTable->render('admin.status.status_list');
    }
    public function add_status_form(Request $request)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/statuses', [
                'status' => $request->status,
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Status added successfully']);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add status.'
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    public function delete_status($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/statuses/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Status deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Unable to delete Status'
            ], $response->status());
        }
    }
    public function update_status_form(Request $request, $id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/statuses/{$id}", [
                'status' => $request->status,
            ]);
    
            if ($response->successful()) {
                return response()->json([
                    'success' => true,
                    'message' => 'Status updated successfully.'
                ]);
            } else {
                // Capture and return error details if available
                $errorDetails = $response->json();
                $errorMessage = $errorDetails['message'] ?? 'Failed to update status.';
                $errors = $errorDetails['errors'] ?? [];
    
                return response()->json([
                    'success' => false,
                    'message' => $errorMessage,
                    'errors' => $errors
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'An error occurred.'
            ], 500);
        }
    }
    
        

    public function get_status($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/statuses/{$id}");

            if ($response->successful()) {
                return response()->json(['status' => $response->json()]);
            } else {
                return response()->json(['status' => 404, 'message' => 'Status not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
}
