<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\DataTables\StudentDataTable;
use Illuminate\Support\Facades\Http;

class StudentController extends Controller
{
    public function student_list(StudentDataTable $dataTable)
    {
        return $dataTable->render('admin.students.students_list');
    }
    public function add_student_form(Request $request)
    {
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email', // Ensure email is unique
            'phone' => 'required|string|max:11', // Ensure phone number is a maximum of 11 characters
            'cnic' => 'required',
            'password' => 'required',
            'address' => 'required',
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/students', [
                'name' => $request->name,
                'email' => $request->email,
                'phone' => $request->phone,
                'cnic' => $request->cnic,
                'password' => $request->password,
                'address' => $request->address,
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'student' => $response->json()['student']]);
            } else {
                $error = $response->json();
                return response()->json(['success' => false, 'message' => $error['message'] ?? 'Failed to add student.'], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'Something went wrong: ' . $e->getMessage()], 500);
        }
    }
    public function delete_student($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/students/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Student deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Student can not be Deleted'
            ], $response->status());
        }
    }
    public function get_student($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/students/{$id}");

            if ($response->successful()) {
                return response()->json(['data' => $response->json()]);
            } else {
                return response()->json(['data' => 404, 'message' => 'Student not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function update_student_form(Request $request, $id)
    {
        // Adding unique validation for email while excluding the current teacher
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email', // Unique check excluding current ID
            'phone' => 'required|string|max:11',
            'cnic' => 'required',
            'password' => 'required',
            'address' => 'required'
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/students/{$id}", [
                'name' => $request->name,
                'email' => $request->email,
                'phone' => $request->phone,
                'cnic' => $request->cnic,
                'password' => $request->password,
                'address' => $request->address,
            ]);
    
            if ($response->successful()) {
                return response()->json(['success' => true, 'message' => 'Student updated successfully.']);
            } else {
                return response()->json(['success' => false, 'message' => $response->json()['message'] ?? 'Failed to update Student.'], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => 'An error occurred: ' . $e->getMessage()], 500);
        }
    }
}
