<?php

namespace App\Http\Controllers;

use Illuminate\Support\Facades\Log;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use App\DataTables\TeachersDataTable;
use Illuminate\Support\Facades\Validator;

class TeacherController extends Controller
{
    public function fetch_courses(): array
    {
        $token = session('bearer_token');

        $response = Http::withToken($token)->get('https://microsols.com.au/api/public/api/course');

        if ($response->successful()) {
            $courses = $response->json()['courses'] ?? [];
            // Extract only the necessary columns
            $course_list = array_map(function ($courses) {
                return [
                    'id' => $courses['id'],
                    'name' => $courses['name'],
                ];
            }, $courses);

            return $course_list;
        }

        return [];
    }
    public function teachers_list(TeachersDataTable $dataTable)
    {
        $courses = $this->fetch_courses();
        return $dataTable->render('admin.teachers.teachers_list' ,compact('courses'));
    }
    public function add_teacher_form(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'email' => 'required|email',
            'phone' => 'required|numeric|digits_between:10,11',
            'cnic' => 'required|numeric|digits_between:10,15',
            'password' => 'required|string',
            'address' => 'required|string',
            'course_ids' => 'required|array',
            'course_ids.*' => 'integer'
        ]);
    
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->post('https://microsols.com.au/api/public/api/teachers', [
                'name' => $request->name,
                'email' => $request->email,
                'phone' => $request->phone,
                'cnic' => $request->cnic,
                'password' => $request->password,
                'address' => $request->address,
                'course_ids' => $request->course_ids,
            ]);
    
            if ($response->successful()) {
                return response()->json([
                    'success' => true,
                    'teacher' => $response->json()['teacher']
                ]);
            } else {
                $error = $response->json();
                return response()->json([
                    'success' => false,
                    'message' => $error['message'] ?? 'Failed to add Teacher.',
                    'errors' => $error['errors'] ?? []
                ], $response->status());
            }
        } catch (\Exception $e) {
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong: ' . $e->getMessage()
            ], 500);
        }
    }
    
    
    
    public function delete_teacher($id)
    {
        $token = session('bearer_token');
        $response = Http::withToken($token)->delete("https://microsols.com.au/api/public/api/teachers/{$id}");

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Teacher deleted successfully']);
        } else {
            // Ensure the error message is correctly fetched from the API response
            $error = $response->json();
            return response()->json([
                'success' => false,
                'message' => $error['message'] ?? 'Teacher to delete Label'
            ], $response->status());
        }
    }
    public function get_teacher($id)
    {
        try {
            $token = session('bearer_token');
            $response = Http::withToken($token)->get("https://microsols.com.au/api/public/api/teachers/{$id}");

            if ($response->successful()) {
                return response()->json(['data' => $response->json()]);
            } else {
                return response()->json(['data' => 404, 'message' => 'Teacher not found.'], 404);
            }
        } catch (\Exception $e) {
            return response()->json(['message' => 'An error occurred.'], 500);
        }
    }
    public function update_teacher_form(Request $request, $id)
{
    // Validate each field individually
    $request->validate([
        'name' => 'required|string|max:255',
        'email' => 'required|email',
        'phone' => 'required|numeric|digits_between:10,11',
        'cnic' => 'required|numeric|digits_between:10,15',
        'password' => 'nullable|string|min:6',
        'address' => 'required|string|max:255',
        'course_ids' => 'required|array',
        'course_ids.*' => 'integer'
    ]);

    try {
        $token = session('bearer_token');
        $response = Http::withToken($token)->put("https://microsols.com.au/api/public/api/teachers/{$id}", [
            'name' => $request->input('name'),
            'email' => $request->input('email'),
            'phone' => $request->input('phone'),
            'cnic' => $request->input('cnic'),
            'password' => $request->input('password'),
            'address' => $request->input('address'),
            'course_ids' => $request->input('course_ids'),
        ]);

        if ($response->successful()) {
            return response()->json(['success' => true, 'message' => 'Teacher updated successfully.']);
        } else {
            return response()->json([
                'success' => false,
                'message' => $response->json()['message'] ?? 'Failed to update Teacher.',
                'errors' => $response->json()['errors'] ?? []
            ], $response->status());
        }
    } catch (\Exception $e) {
        return response()->json(['success' => false, 'message' => 'An error occurred: ' . $e->getMessage()], 500);
    }
}

    
    
}
