@extends('admin.layout.main')

@section('content')
    @push('meta')
        <meta name="csrf-token" content="{{ csrf_token() }}">
    @endpush

    @push('styles')
        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
        <script src="https://cdn.datatables.net/1.10.25/js/jquery.dataTables.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
        <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/css/select2.min.css">
        <script src="https://cdnjs.cloudflare.com/ajax/libs/select2/4.0.13/js/select2.min.js"></script>
    @endpush

    <div class="breadcrumbbar">
        <div class="row align-items-center">
            <div class="col-md-8 col-lg-8">
                <div class="breadcrumb-list">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ route('home') }}">Home</a></li>
                        <li class="breadcrumb-item"><a href="{{ route('status_list') }}">Status</a></li>
                        <li class="breadcrumb-item active" aria-current="page">Status List</li>
                    </ol>
                </div>
            </div>
            <div class="col-md-4 col-lg-4">
                <div class="widgetbar">
                    <button class="btn btn-primary-rgba" id="addStatus">Add Status</button>
                </div>
            </div>
        </div>
    </div>

    <!-- Start Contentbar -->
    <div class="contentbar">
        <div class="row">
            <div class="col-lg-12">
                <div class="card m-b-30">
                    <div class="card-header">
                        <h5 class="card-title">Status Table</h5>
                    </div>
                    <div class="card-body">
                        <div class="table-responsive" style="overflow-x: scroll">
                            <table id="status_table" class="table-bordered category-table display table">
                                <thead>
                                    <tr>
                                        <th>ID</th>
                                        <th>Status</th>
                                        <th>Created at</th>
                                        <th>Updated at</th>

                                        <th>Action</th>
                                    </tr>
                                </thead>
                                <tbody></tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Add Course Modal -->
    <div class="modal fade" id="createStatusModal" tabindex="-1" role="dialog" aria-labelledby="createStatusModalLabel"
        aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="createStatusModalLabel">Add Status</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form id="createStatusForm">
                    <div class="modal-body">
                        <div class="form-group">
                            <label for="course-name">Status</label>
                            <input type="text" class="form-control" id="status" name="status" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Add Status</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <div class="modal fade" id="updateStatusModal" tabindex="-1" role="dialog" aria-labelledby="updateStatusModalLabel"
        aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="updateStatusModalLabel">Update Status</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <form id="updateStatusForm">
                    <div class="modal-body">
                        <input type="hidden" id="status_id" name="status_id">
                        <div class="form-group">
                            <label for="course-name">Status</label>
                            <input type="text" class="form-control" id="status_update" name="status" required>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="submit" class="btn btn-primary">Update</button>
                    </div>
                </form>
            </div>
        </div>
    </div>


    @push('scripts')
        <script>
            $(document).ready(function() {
                var table = $('#status_table').DataTable({
                    processing: true,
                    serverSide: true,
                    ajax: '{{ route('status_list') }}',
                    columns: [{
                            data: 'id',
                            name: 'id'
                        },
                        {
                            data: 'status',
                            name: 'status'
                        },
                        {
                            data: 'created_at',
                            name: 'created_at',
                            render: function(data, type, row) {
                                return new Date(data).toLocaleDateString();
                            }
                        },
                        {
                            data: 'updated_at',
                            name: 'updated_at',
                            render: function(data, type, row) {
                                return new Date(data).toLocaleDateString();
                            }
                        },
                        {
                            data: null,
                            name: 'action',
                            render: function(data, type, row) {
                                return `
                        <button type="button" class="btn btn-round btn-secondary" data-id="${row.id}" id="editStatus"><i class="feather icon-edit"></i></button>
                        <button type="button" class="btn btn-round btn-danger" data-id="${row.id}" id="deleteStatus"><i class="feather icon-trash-2"></i></button>
                    `;
                            }
                        }
                    ]
                });


                $('#addStatus').on('click', function() {
                    $('#createStatusModal').modal('show');
                });

                $('#createStatusForm').on('submit', function(e) {
                    e.preventDefault();

                    // Disable the submit button to prevent multiple submissions
                    let $submitButton = $('#createStatusForm button[type="submit"]');
                    $submitButton.prop('disabled', true);

                    $.ajax({
                        type: 'POST',
                        headers: {
                            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                        },
                        url: "{{ route('add_status_form') }}",
                        data: $(this).serialize(),
                        success: function(response) {
                            console.log("Response:", response); // Log the response for debugging
                            if (response.success) {
                                $('#createStatusModal').modal('hide');
                                $('#status_table').DataTable().ajax.reload();
                                Swal.fire('Added!', 'The Status has been added.', 'success');
                                $('#createStatusForm')[0].reset();
                            } else {
                                // If response contains validation errors
                                let errorMessage = response.message;
                                if (response.errors && response.errors.length > 0) {
                                    errorMessage += '<br><br>Errors:<ul>';
                                    response.errors.forEach(function(error) {
                                        errorMessage += '<li>' + error + '</li>';
                                    });
                                    errorMessage += '</ul>';
                                }
                                Swal.fire('Error!', errorMessage, 'error');
                            }
                        },
                        error: function(xhr) {
                            console.log("AJAX Error:", xhr); // Log the error for debugging
                            Swal.fire('Error!', 'Something went wrong.', 'error');
                        },
                        complete: function() {
                            // Re-enable the submit button after the request completes
                            $submitButton.prop('disabled', false);
                        }
                    });
                });



                $('body').on('click', '#deleteStatus', function() {
                    var id = $(this).data('id');

                    Swal.fire({
                        title: 'Are you sure?',
                        text: "You won't be able to revert this!",
                        // Use 'warning' for better visibility
                        showCancelButton: true,

                        confirmButtonText: 'Yes, delete it!',
                        cancelButtonText: 'No, cancel!',

                    }).then((result) => {
                        if (result.isConfirmed) {
                            $.ajax({
                                type: "DELETE",
                                headers: {
                                    'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                                },
                                url: "{{ route('delete_status', ['id' => ':id']) }}"
                                    .replace(':id', id),
                                success: function(response) {
                                    table.ajax.reload();
                                    Swal.fire('Deleted!',
                                        'The Status has been deleted.', 'success');
                                },
                                error: function(xhr) {
                                    Swal.fire('Error!', 'An error occurred.', 'error');
                                }
                            });
                        }
                    });
                });

                $('body').on('click', '#editStatus', function() {
                    var id = $(this).data('id');
                    $.ajax({
                        type: "GET",
                        headers: {
                            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                        },
                        url: "{{ route('get_status', ['id' => ':id']) }}".replace(':id', id),
                        success: function(response) {
                            if (response.status == 404) {
                                Swal.fire('Error!', response.message, 'error');
                                $('#updateStatusModal').modal('hide');
                            } else {
                                var status = response.status;
                                $('#status_id').val(status.status.id);
                                $('#status_update').val(status.status.status);
                                $('#updateStatusModal').modal('show');
                            }
                        },
                        error: function(xhr) {
                            Swal.fire('Error!', 'Something went wrong.', 'error');
                        }
                    });
                });
                $('#updateStatusForm').on('submit', function(e) {
    e.preventDefault();
    
    var id = $('#status_id').val(); // Ensure this value is set correctly

    // Disable the submit button to prevent multiple submissions
    let $submitButton = $('#updateStatusForm button[type="submit"]');
    $submitButton.prop('disabled', true);

    $.ajax({
        type: 'PUT',
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        },
        url: "{{ route('update_status_form', ['id' => ':id']) }}".replace(':id', id),
        data: $(this).serialize(),
        success: function(response) {
            console.log("AJAX Success:", response); // Log response for debugging

            if (response.success) {
                $('#updateStatusModal').modal('hide');
                $('#status_table').DataTable().ajax.reload(); // Ensure table variable is correct
                Swal.fire('Updated!', response.message || 'The status has been updated.', 'success');
                $('#updateStatusForm')[0].reset();
            } else {
                // Handle validation or other errors
                let errorMessage = response.message || 'An error occurred.';
                if (response.errors && response.errors.length > 0) {
                    errorMessage += '<br><br>Errors:<ul>';
                    response.errors.forEach(function(error) {
                        errorMessage += '<li>' + error + '</li>';
                    });
                    errorMessage += '</ul>';
                }
                Swal.fire('Error!', errorMessage, 'error');
            }
        },
        error: function(xhr) {
            console.log("AJAX Error:", xhr); // Log the error for debugging
            let errorMessage = 'An unexpected error occurred.';
            if (xhr.responseJSON && xhr.responseJSON.message) {
                errorMessage = xhr.responseJSON.message;
            }
            Swal.fire('Error!', errorMessage, 'error');
        },
        complete: function() {
            // Re-enable the submit button after the request completes
            $submitButton.prop('disabled', false);
        }
    });
});

            });
        </script>
    @endpush
@endsection
