<?php

use Illuminate\Support\Facades\Route;
use App\Http\Controllers\AuthController;
use App\Http\Controllers\LabelController;
use App\Http\Controllers\LeadsController;
use App\Http\Controllers\PagesController;
use App\Http\Controllers\RolesController;
use App\Http\Controllers\StatusController;
use App\Http\Controllers\CoursesController;
use App\Http\Controllers\EnrollController;
use App\Http\Controllers\PermissionController;
use App\Http\Controllers\Settings\UserController;
use App\Http\Controllers\StudentController;
use App\Http\Controllers\TeacherController;
use App\Http\Controllers\TrialController;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

Route::middleware('guest')->group(function () {
    Route::get('/login', [AuthController::class, 'login_view'])->name('login_view');
    Route::post('/login', [AuthController::class, 'login'])->name('login');
});

// Authenticated routes
Route::middleware('check.token')->group(function () {
    Route::post('/logout', [AuthController::class, 'logout'])->name('logout');


    Route::get('/', [CoursesController::class, 'home'])->name('home');


    Route::get('/courses_list', [CoursesController::class, 'courses_list'])->name('courses_list');
    Route::post('/courses/store', [CoursesController::class, 'storeCourse'])->name('courses.store');
    Route::delete('/courses/{id}', [CoursesController::class, 'deleteCourse'])->name('courses.delete');
    Route::get('/courses/{id}/edit', [CoursesController::class, 'getCourse'])->name('courses.update_form');
    Route::put('/courses/{id}', [CoursesController::class, 'updateCourse'])->name('courses.update');
    
    //leads
    Route::get('/leads_list', [LeadsController::class, 'leads_list'])->name('leads_list');
    Route::get('/get_lead/{id}', [LeadsController::class, 'get_lead'])->name('get_lead');
    Route::post('/add_lead_form', [LeadsController::class, 'add_lead_form'])->name('add_lead_form');
    Route::post('/add_leads_label_form', [LeadsController::class, 'add_leads_label_form'])->name('add_leads_label_form');
    Route::post('/add_feedback_form', [LeadsController::class, 'add_feedback_form'])->name('add_feedback_form');
    Route::post('/add_lead_trial_form', [LeadsController::class, 'add_lead_trial_form'])->name('add_lead_trial_form');
    Route::delete('/delete_lead/{id}', [LeadsController::class, 'delete_lead'])->name('delete_lead');
    Route::put('/update_lead_form/{id}', [LeadsController::class, 'update_lead_form'])->name('update_lead_form');
    Route::get('/timeline/{id}' , [LeadsController::class,'timeline'])->name('timeline');
 
   //status
    Route::get('/status_list', [StatusController::class, 'status_list'])->name('status_list');
    Route::get('/get_status/{id}', [StatusController::class, 'get_status'])->name('get_status');
    Route::post('/add_status_form', [StatusController::class, 'add_status_form'])->name('add_status_form');
    Route::delete('/delete_status/{id}', [StatusController::class, 'delete_status'])->name('delete_status');
    Route::put('/update_status_form/{id}', [StatusController::class, 'update_status_form'])->name('update_status_form');
    
    //trials
    Route::get('/trials_list', [TrialController::class, 'trials_list'])->name('trials_list');
    Route::delete('/delete_trial/{id}', [TrialController::class, 'delete_trial'])->name('delete_trial');
    Route::post('/add_trial_form', [TrialController::class, 'add_trial_form'])->name('add_trial_form');
    Route::get('/get_trial/{id}', [TrialController::class, 'get_trial'])->name('get_trial');
    Route::put('/update_trial_form/{id}', [TrialController::class, 'update_trial_form'])->name('update_trial_form');
  
  
    //label
    Route::get('/label_list', [LabelController::class, 'label_list'])->name('label_list');
    Route::get('/get_label/{id}', [LabelController::class, 'get_label'])->name('get_label');
    Route::post('/add_label_form', [LabelController::class, 'add_label_form'])->name('add_label_form');
    Route::delete('/delete_label/{id}', [LabelController::class, 'delete_label'])->name('delete_label');
    Route::put('/update_label_form/{id}', [LabelController::class, 'update_label_form'])->name('update_label_form');


    //permission
    Route::get('/permission_list', [PermissionController::class, 'permission_list'])->name('permission_list');
    Route::get('/get_permission/{id}', [PermissionController::class, 'get_permission'])->name('get_permission');
    Route::post('/add_permission_form', [PermissionController::class, 'add_permission_form'])->name('add_permission_form');
    Route::delete('/delete_permission/{id}', [PermissionController::class, 'delete_permission'])->name('delete_permission');
    Route::put('/update_permission_form/{id}', [PermissionController::class, 'update_permission_form'])->name('update_permission_form');
   
    //roles
    Route::get('/roles_list', [RolesController::class, 'roles_list'])->name('roles_list');
    Route::get('/get_role/{id}', [RolesController::class, 'get_role'])->name('get_role');
    Route::post('/add_role_form', [RolesController::class, 'add_role_form'])->name('add_role_form');
    Route::post('/assign_permission', [RolesController::class, 'assign_permission'])->name('assign_permission');
    Route::delete('/delete_role/{id}', [RolesController::class, 'delete_role'])->name('delete_role');
    Route::put('/update_role_form/{id}', [RolesController::class, 'update_role_form'])->name('update_role_form');
    

    //teachers
    Route::get('/teachers_list', [TeacherController::class, 'teachers_list'])->name('teachers_list');
    Route::post('/add_teacher_form', [TeacherController::class, 'add_teacher_form'])->name('add_teacher_form');
    Route::delete('/delete_teacher/{id}', [TeacherController::class, 'delete_teacher'])->name('delete_teacher');
    Route::get('/get_teacher/{id}', [TeacherController::class, 'get_teacher'])->name('get_teacher');
    Route::put('/update_teacher_form/{id}', [TeacherController::class, 'update_teacher_form'])->name('update_teacher_form');


    Route::get('/user_list' ,[UserController::class,'user_list'])->name('user_list');
    Route::get('/get_user/{id}', [UserController::class, 'get_user'])->name('get_user');
    Route::post('/add_user_form', [UserController::class, 'add_user_form'])->name('add_user_form');
    Route::delete('/delete_user/{id}', [UserController::class, 'delete_user'])->name('delete_user');
    Route::put('/update_user_form/{id}', [UserController::class, 'update_user_form'])->name('update_user_form');

    Route::get('/student_list' ,[StudentController::class,'student_list'])->name('student_list');
    Route::post('/add_student_form', [StudentController::class, 'add_student_form'])->name('add_student_form');
    Route::get('/get_student/{id}', [StudentController::class, 'get_student'])->name('get_student');
    Route::delete('/delete_student/{id}', [StudentController::class, 'delete_student'])->name('delete_student');
    Route::put('/update_student_form/{id}', [StudentController::class, 'update_student_form'])->name('update_student_form');
    
    Route::get('/enrollments_list' ,[EnrollController::class,'enrollments_list'])->name('enrollments_list');
    Route::get('/get_lead_courses/{id}', [EnrollController::class, 'get_lead_courses'])->name('get_lead_courses');
    Route::post('/add_enrollment_form', [EnrollController::class, 'add_enrollment_form'])->name('add_enrollment_form');
    Route::get('/get_enrollment/{id}', [EnrollController::class, 'get_enrollment'])->name('get_enrollment');
    Route::get('/update_enrollment/{id}', [EnrollController::class, 'update_enrollment'])->name('update_enrollment');
    Route::put('/update_enrollment_form/{id}', [EnrollController::class, 'update_enrollment_form'])->name('update_enrollment_form');
    Route::delete('/delete_enrollment/{id}', [EnrollController::class, 'delete_enrollment'])->name('delete_enrollment');
});
